==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Base/Func/LinearNumericalMathEvaluationImplementation.cxx <==
//                                               -*- C++ -*-
/**
 * @file  LinearNumericalMathEvaluationImplementation.cxx
 * @brief Class for a linear numerical math function implementation
 *        of the form y = constant + <linear, x - c> where c is a
 *        dim(x) numerical point, linear a dim(x) by dim(y) matrix
 *        and  <linear, x - c> means Transpose(linear).(x - c)
 *
 * (C) Copyright 2005-2006 EADS
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 *
 * \author $LastChangedBy: dutka $
 * \date   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 */

#include "LinearNumericalMathEvaluationImplementation.hxx"
#include "PersistentObjectFactory.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Func {

      CLASSNAMEINIT(LinearNumericalMathEvaluationImplementation);

      static Common::Factory<LinearNumericalMathEvaluationImplementation> RegisteredFactory("LinearNumericalMathEvaluationImplementation");

      /* Default constructor */
      LinearNumericalMathEvaluationImplementation::LinearNumericalMathEvaluationImplementation()
	: NumericalMathEvaluationImplementation()
      {
	// Nothing to do
      }

      /* Parameter constructor */
      LinearNumericalMathEvaluationImplementation::LinearNumericalMathEvaluationImplementation(const NumericalPoint & center,
											       const NumericalPoint & constant,
											       const Matrix & linear)
        throw(InvalidDimensionException) :
        NumericalMathEvaluationImplementation(),
	center_(center),
        constant_(constant),
	linear_(linear.transpose())
      {
	/* Check if the dimension of the constant term is compatible with the linear term */
        if (constant.getDimension() != linear.getNbColumns()) throw InvalidDimensionException(HERE) << "Constant term dimension is incompatible with the linear term";
	/* Check if the dimension of the center term is compatible with the linear term */
        if (center.getDimension() != linear.getNbRows()) throw InvalidDimensionException(HERE) << "Center term dimension is incompatible with the linear term";
	Description description;
	for (UnsignedLong i = 0; i < center.getDimension(); i++)
	  {
	    OSS oss;
	    oss << "x" << i;
	    description.add(oss);
	  }
	for (UnsignedLong i = 0; i < constant.getDimension(); i++)
	  {
	    OSS oss;
	    oss << "y" << i;
	    description.add(oss);
	  }
	setDescription(description);
      }

      /* Virtual constructor */
      LinearNumericalMathEvaluationImplementation * LinearNumericalMathEvaluationImplementation::clone() const
      {
	return new LinearNumericalMathEvaluationImplementation(*this);
      }

      /* Comparison operator */
      Bool LinearNumericalMathEvaluationImplementation::operator ==(const LinearNumericalMathEvaluationImplementation & other) const
      {
	return ((linear_ == other.linear_) && (constant_ == other.constant_) && (center_ == other.center_));
      }
  
      /* String converter */
      String LinearNumericalMathEvaluationImplementation::str() const {
	OSS oss;
	oss << "class=" << LinearNumericalMathEvaluationImplementation::GetClassName()
	    << " name=" << getName()
	    << " center=" << center_
            << " constant=" << constant_
            << " linear=" << linear_.transpose();
	return oss;
      }
  
      /* Accessor for the center */
      LinearNumericalMathEvaluationImplementation::NumericalPoint LinearNumericalMathEvaluationImplementation::getCenter() const
      {
	return center_;
      }

      /* Accessor for the constant term */
      LinearNumericalMathEvaluationImplementation::NumericalPoint LinearNumericalMathEvaluationImplementation::getConstant() const
      {
	return constant_;
      }

      /* Accessor for the linear term */
      LinearNumericalMathEvaluationImplementation::Matrix LinearNumericalMathEvaluationImplementation::getLinear() const
      {
	return linear_.transpose();
      }

      /* Here is the interface that all derived class must implement */
	
      /* Operator () */
      LinearNumericalMathEvaluationImplementation::NumericalPoint LinearNumericalMathEvaluationImplementation::operator() (const NumericalPoint & in) const
	throw(InvalidArgumentException, InternalException)
      {
	if (in.getDimension() != center_.getDimension()) throw InvalidArgumentException(HERE) << "Invalid input dimension";
	callsNumber_++;
	return constant_ + linear_ * (in - center_);
      }
      /* Operator () */
      LinearNumericalMathEvaluationImplementation::NumericalSample LinearNumericalMathEvaluationImplementation::operator() (const NumericalSample & in) const
	throw(InvalidArgumentException, InternalException)
      {
	return NumericalMathEvaluationImplementation::operator()(in);
      }

      /* Accessor for input point dimension */
      UnsignedLong LinearNumericalMathEvaluationImplementation::getInputNumericalPointDimension() const
	throw(InternalException)
      {
	return center_.getDimension();
      }
      
      /* Accessor for output point dimension */
      UnsignedLong LinearNumericalMathEvaluationImplementation::getOutputNumericalPointDimension() const
	throw(InternalException)
      {
	return constant_.getDimension();
      }
      
      /* Method save() stores the object through the StorageManager */
      void LinearNumericalMathEvaluationImplementation::save(const StorageManager::Advocate & adv) const
      {
	NumericalMathEvaluationImplementation::save(adv);
	adv.writeValue(center_, StorageManager::MemberNameAttribute, "center_");
	adv.writeValue(constant_, StorageManager::MemberNameAttribute, "constant_");
	adv.writeValue(linear_, StorageManager::MemberNameAttribute, "linear_");
      }

      /* Method load() reloads the object from the StorageManager */
      void LinearNumericalMathEvaluationImplementation::load(const StorageManager::Advocate & adv)
      {
	NumericalMathEvaluationImplementation::load(adv);
	StorageManager::List objList = adv.getList(StorageManager::ObjectEntity);
	objList.readValue(center_,  StorageManager::MemberNameAttribute, "center_");
	objList.readValue(constant_,  StorageManager::MemberNameAttribute, "constant_");
	objList.readValue(linear_, StorageManager::MemberNameAttribute, "linear_");
      }

    } /* namespace Func */
  } /* namespace Base */
} /* namespace OpenTURNS */

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Base/Func/LinearNumericalMathEvaluationImplementation.cxx <==
//                                               -*- C++ -*-
/**
 * @file  LinearNumericalMathEvaluationImplementation.cxx
 * @brief Class for a linear numerical math function implementation
 *        of the form y = constant + <linear, x - c> where c is a
 *        dim(x) numerical point, linear a dim(x) by dim(y) matrix
 *        and  <linear, x - c> means Transpose(linear).(x - c)
 *
 * (C) Copyright 2005-2006 EADS
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 *
 * \author $LastChangedBy: dutka $
 * \date   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 */

#include "LinearNumericalMathEvaluationImplementation.hxx"
#include "PersistentObjectFactory.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Func {

      CLASSNAMEINIT(LinearNumericalMathEvaluationImplementation);

      static Common::Factory<LinearNumericalMathEvaluationImplementation> RegisteredFactory("LinearNumericalMathEvaluationImplementation");

      /* Default constructor */
      LinearNumericalMathEvaluationImplementation::LinearNumericalMathEvaluationImplementation()
	: NumericalMathEvaluationImplementation()
      {
	// Nothing to do
      }

      /* Parameter constructor */
      LinearNumericalMathEvaluationImplementation::LinearNumericalMathEvaluationImplementation(const NumericalPoint & center,
											       const NumericalPoint & constant,
											       const Matrix & linear)
        throw(InvalidDimensionException) :
        NumericalMathEvaluationImplementation(),
	center_(center),
        constant_(constant),
	linear_(linear.transpose())
      {
	/* Check if the dimension of the constant term is compatible with the linear term */
        if (constant.getDimension() != linear.getNbColumns()) throw InvalidDimensionException(HERE) << "Constant term dimension is incompatible with the linear term";
	/* Check if the dimension of the center term is compatible with the linear term */
        if (center.getDimension() != linear.getNbRows()) throw InvalidDimensionException(HERE) << "Center term dimension is incompatible with the linear term";
	Description description;
	for (UnsignedLong i = 0; i < center.getDimension(); i++)
	  {
	    OSS oss;
	    oss << "x" << i;
	    description.add(oss);
	  }
	for (UnsignedLong i = 0; i < constant.getDimension(); i++)
	  {
	    OSS oss;
	    oss << "y" << i;
	    description.add(oss);
	  }
	setDescription(description);
      }

      /* Virtual constructor */
      LinearNumericalMathEvaluationImplementation * LinearNumericalMathEvaluationImplementation::clone() const
      {
	return new LinearNumericalMathEvaluationImplementation(*this);
      }

      /* Comparison operator */
      Bool LinearNumericalMathEvaluationImplementation::operator ==(const LinearNumericalMathEvaluationImplementation & other) const
      {
	return ((linear_ == other.linear_) && (constant_ == other.constant_) && (center_ == other.center_));
      }
  
      /* String converter */
      String LinearNumericalMathEvaluationImplementation::__repr__() const {
	OSS oss;
	oss << "class=" << LinearNumericalMathEvaluationImplementation::GetClassName()
	    << " name=" << getName()
	    << " center=" << center_.__repr__()
            << " constant=" << constant_.__repr__()
            << " linear=" << linear_.transpose();
	return oss;
      }
  
      /* Accessor for the center */
      LinearNumericalMathEvaluationImplementation::NumericalPoint LinearNumericalMathEvaluationImplementation::getCenter() const
      {
	return center_;
      }

      /* Accessor for the constant term */
      LinearNumericalMathEvaluationImplementation::NumericalPoint LinearNumericalMathEvaluationImplementation::getConstant() const
      {
	return constant_;
      }

      /* Accessor for the linear term */
      LinearNumericalMathEvaluationImplementation::Matrix LinearNumericalMathEvaluationImplementation::getLinear() const
      {
	return linear_.transpose();
      }

      /* Here is the interface that all derived class must implement */
	
      /* Operator () */
      LinearNumericalMathEvaluationImplementation::NumericalPoint LinearNumericalMathEvaluationImplementation::operator() (const NumericalPoint & in) const
	throw(InvalidArgumentException, InternalException)
      {
	if (in.getDimension() != center_.getDimension()) throw InvalidArgumentException(HERE) << "Invalid input dimension";
	callsNumber_++;
	return constant_ + linear_ * (in - center_);
      }
      /* Operator () */
      LinearNumericalMathEvaluationImplementation::NumericalSample LinearNumericalMathEvaluationImplementation::operator() (const NumericalSample & in) const
	throw(InvalidArgumentException, InternalException)
      {
	return NumericalMathEvaluationImplementation::operator()(in);
      }

      /* Accessor for input point dimension */
      UnsignedLong LinearNumericalMathEvaluationImplementation::getInputNumericalPointDimension() const
	throw(InternalException)
      {
	return center_.getDimension();
      }
      
      /* Accessor for output point dimension */
      UnsignedLong LinearNumericalMathEvaluationImplementation::getOutputNumericalPointDimension() const
	throw(InternalException)
      {
	return constant_.getDimension();
      }
      
      /* Method save() stores the object through the StorageManager */
      void LinearNumericalMathEvaluationImplementation::save(const StorageManager::Advocate & adv) const
      {
	NumericalMathEvaluationImplementation::save(adv);
	adv.writeValue(center_, StorageManager::MemberNameAttribute, "center_");
	adv.writeValue(constant_, StorageManager::MemberNameAttribute, "constant_");
	adv.writeValue(linear_, StorageManager::MemberNameAttribute, "linear_");
      }

      /* Method load() reloads the object from the StorageManager */
      void LinearNumericalMathEvaluationImplementation::load(const StorageManager::Advocate & adv)
      {
	NumericalMathEvaluationImplementation::load(adv);
	StorageManager::List objList = adv.getList(StorageManager::ObjectEntity);
	objList.readValue(center_,  StorageManager::MemberNameAttribute, "center_");
	objList.readValue(constant_,  StorageManager::MemberNameAttribute, "constant_");
	objList.readValue(linear_, StorageManager::MemberNameAttribute, "linear_");
      }

    } /* namespace Func */
  } /* namespace Base */
} /* namespace OpenTURNS */
